@@ -3,15 +3,18 @@ knitr::opts_chunk$set(
   message = FALSE,
   digits = 3,
   collapse = TRUE,
-  comment = "#>"
+  comment = "#>",
+  eval = rlang::is_installed("ggplot2") && rlang::is_installed("modeldata")
   )
 options(digits = 3, width = 90)
+
+## ----ggplot2_setup, include = FALSE-----------------------------------------------------
 library(ggplot2)
 theme_set(theme_bw())
 
 ## ----attrition, message=FALSE-----------------------------------------------------------
 library(rsample)
-data("attrition")
+data("attrition", package = "modeldata")
 names(attrition)
 table(attrition$Attrition)
 
@@ -21,11 +24,10 @@ mod_form <- as.formula(Attrition ~ JobSatisfaction + Gender + MonthlyIncome)
 ## ----model_vfold, message=FALSE---------------------------------------------------------
 library(rsample)
 set.seed(4622)
-rs_obj <- vfold_cv(attrition, V = 10, repeats = 10)
+rs_obj <- vfold_cv(attrition, v = 10, repeats = 10)
 rs_obj
 
 ## ----lm_func----------------------------------------------------------------------------
-library(broom)
 ## splits will be the `rsplit` object with the 90/10 partition
 holdout_results <- function(splits, ...) {
   # Fit the model to the 90%
@@ -88,7 +90,7 @@ ggplot(bt_resamples, aes(x = wage_diff)) +
 
 ## ----ci---------------------------------------------------------------------------------
 quantile(bt_resamples$wage_diff, 
-         probs = c(0.025, 0.500, 0.975))
+         probs = c(0.025, 0.975))
 
 ## ----coefs------------------------------------------------------------------------------
 glm_coefs <- function(splits, ...) {
